@@ -2,7 +2,7 @@
  *
  *  Connection Manager
  *
- *  Copyright (C) 2007-2010  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2007-2012  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -37,24 +37,27 @@
 
 #include <gdbus.h>
 
-#ifdef HAVE_CAPNG
-#include <cap-ng.h>
-#endif
-
 #include "connman.h"
 
+#define DEFAULT_INPUT_REQUEST_TIMEOUT 120 * 1000
+#define DEFAULT_BROWSER_LAUNCH_TIMEOUT 300 * 1000
+
 static struct {
 	connman_bool_t bg_scan;
 	char **pref_timeservers;
 	unsigned int *auto_connect;
 	unsigned int *preferred_techs;
 	char **fallback_nameservers;
+	unsigned int timeout_inputreq;
+	unsigned int timeout_browserlaunch;
 } connman_settings  = {
 	.bg_scan = TRUE,
 	.pref_timeservers = NULL,
 	.auto_connect = NULL,
 	.preferred_techs = NULL,
 	.fallback_nameservers = NULL,
+	.timeout_inputreq = DEFAULT_INPUT_REQUEST_TIMEOUT,
+	.timeout_browserlaunch = DEFAULT_BROWSER_LAUNCH_TIMEOUT,
 };
 
 static GKeyFile *load_config(const char *file)
@@ -146,10 +149,15 @@ static void parse_config(GKeyFile *config)
 		"wifi",
 		"ethernet",
 		"cellular",
+		NULL
 	};
+	int timeout;
 
-	if (config == NULL)
+	if (config == NULL) {
+		connman_settings.auto_connect =
+			parse_service_types(default_auto_connect, 3);
 		return;
+	}
 
 	DBG("parsing main.conf");
 
@@ -202,6 +210,20 @@ static void parse_config(GKeyFile *config)
 	g_strfreev(str_list);
 
 	g_clear_error(&error);
+
+	timeout = g_key_file_get_integer(config, "General",
+			"InputRequestTimeout", &error);
+	if (error == NULL && timeout >= 0)
+		connman_settings.timeout_inputreq = timeout * 1000;
+
+	g_clear_error(&error);
+
+	timeout = g_key_file_get_integer(config, "General",
+			"BrowserLaunchTimeout", &error);
+	if (error == NULL && timeout >= 0)
+		connman_settings.timeout_browserlaunch = timeout * 1000;
+
+	g_clear_error(&error);
 }
 
 static GMainLoop *main_loop = NULL;
@@ -374,6 +396,14 @@ unsigned int *connman_setting_get_uint_list(const char *key)
 	return NULL;
 }
 
+unsigned int connman_timeout_input_request(void) {
+	return connman_settings.timeout_inputreq;
+}
+
+unsigned int connman_timeout_browser_launch(void) {
+	return connman_settings.timeout_browserlaunch;
+}
+
 int main(int argc, char *argv[])
 {
 	GOptionContext *context;
@@ -383,10 +413,6 @@ int main(int argc, char *argv[])
 	GKeyFile *config;
 	guint signal;
 
-#ifdef HAVE_CAPNG
-	/* Drop capabilities */
-#endif
-
 #ifdef NEED_THREADS
 	if (g_thread_supported() == FALSE)
 		g_thread_init(NULL);
@@ -462,10 +488,9 @@ int main(int argc, char *argv[])
 	__connman_dbus_init(conn);
 
 	config = load_config(CONFIGDIR "/main.conf");
-	if (config != NULL) {
-		parse_config(config);
+	parse_config(config);
+	if (config != NULL)
 		g_key_file_free(config);
-	}
 
 	__connman_storage_migrate();
 	__connman_technology_init();
